import cx_Oracle
import time

import airflow_util_dv.sql_util as sqlutil



if __name__ == '__main__':
    # def spool_csv(self, spool_path,data_path,data_type,sql_name,conn,daily_conn,system_type,database,ods_conn):
    #
    # op_kwargs = {'spool_path':'/Users/liuboxue/Documents/workspace/DWH_AIRFLOW_ODS_SQL/RETAIL/RTL/',
    #              'data_path':  '/Users/liuboxue/Documents/workspace/DWH_AIRFLOW_ODS_SQL/RETAIL/RTL/',
    #              'system_type': 'RTL',
    #              'data_type': 'RTL1',
    #              'sql_name': 'arch_city.sql',
    #              'conn': 'DMT2_RETAIL/D77EeKsM@10.20.31.17/RTLPRDDB',
    #              'daily_conn': 'k_ods/WrnN9Szg@10.20.201.216:1521/DDMUATDB',
    #              'ods_conn': 'k_ods/WrnN9Szg@10.20.201.216:1521/DDMUATDB',
    #              'database': 'ORACLE'
    #              }

    airflow_util_dv = sqlutil.AirflowUtil()
    print(time.strftime('%Y.%m.%d %T', time.localtime(time.time())))
    airflow_util_dv.spool_csv('/u01/python/airflow/dags/DWH_AIRFLOW_ODS_SQL/CBB/sh/','/integration_ods_dev/spool_data/isit/',
                          'RTL1','AF_ARR_CASH_FLOW_D.sql','mysql/2wsx*IK<@10.20.202.184:3306/cbb',
                          'k_ods/WrnN9Szg@10.20.201.216:1521/DDMUATDB',
                          'RTL','MYSQL',''
                          )
    print(time.strftime('%Y.%m.%d %T',time.localtime(time.time())))


import fcntl
import os, time

if __name__ == '__main__':

    FILE = "/Users/liuboxue/Desktop/test.txt"
    #
    # if not os.path.exists(FILE):
    #     # create the counter file if it doesn't exist
    #     file = open(FILE, "w")
    #     file.write("0")
    #     file.close()
    #
    # for i in range(20):
    #     file = open(FILE, "r+")  # 由于flock生成的是劝告锁，不能阻止进程对文件的操作，所以这里可以正常打开文件
    #     fcntl.flock(file.fileno(), fcntl.LOCK_EX)  # 为了避免同时操作文件，需要程序自己来检查该文件是否已经被加锁。这里如果检查到加锁了，进程会被阻塞
    #     print('acquire lock')
    #     counter = int(file.readline()) + 1
    #     file.seek(0)
    #     file.write(str(counter))
    #     print
    #     os.getpid(), "=>", counter
    #     time.sleep(10)
    #     file.close()  # unlocks the file
    #     print
    #     'release lock'
    #     time.sleep(3)
    for i in range(2):
        with open(FILE,'w+') as f:
            f.write('123')



import os

import cx_Oracle
import time

from airflow_util_dv.sql_util import AirflowUtil


def data_export(file_path, conn, schema, table_name):
    try:
        if not os.path.exists(file_path):
            raise Exception("文件不存在")
        else:
            connect = cx_Oracle.connect(conn, encoding='gb18030')
            cursor = connect.cursor()
            with open(file_path, 'r', encoding='gb18030') as f:
                list_ = f.readlines()
                sql = 'INSERT ALL '
                sql_retail = 'INSERT ALL '
                sql_suffix = ' SELECT 1 FROM DUAL '
                note_num = 0
                for i in list_:
                    note_num += 1
                    i = i.replace('\n', '')
                    a = i.split('<>')
                    sql1 = ' INTO ' + str(schema) + '.' + str(table_name) + ' VALUES ' + str(tuple(a))
                    sql += sql1
                    if note_num >= 1000:
                        note_num = 0
                        cursor.execute(sql+sql_suffix)
                        connect.commit()
                        sql = sql_retail
                if not note_num == 0:
                    sql += sql_suffix
                    cursor.execute(sql)
                    connect.commit()
                cursor.close()
                connect.close()
                f.close()
    except Exception as e:
        raise Exception("导入数据出错", str(e))


if __name__ == '__main__':
    # airflow_util_dv = AirflowUtil()
    daily_sql = "SELECT  count(1) FROM K_ODS.FIN_DAILY_TABLE  WHERE SYSTEM_ID = '%s' AND TASK_ID = '%s' AND EFF_FLAG = 1   " \
                "AND trunc(THIS_POST_DATE) = trunc(sysdate)"
    connect = cx_Oracle.connect('k_ods/WrnN9Szg@10.20.201.216:1521/DDMUATDB', encoding='gb18030')
    cursor = connect.cursor()
    # file_path = '/dwh_ods_uat/spool_data/RTL/ODS_LN_CS_PRT_REPYMTSKD.csv'
    # # file_path = '/Users/liuboxue/Desktop/ARCH_CITY.csv'
    # data_export(file_path, 'k_ods/WrnN9Szg@10.20.201.216:1521/DDMUATDB', 'K_ODS', 'ODS_LN_CS_PRT_REPYMTSKD_TEST')
    sql = daily_sql % ('DW', 'DW_RTL_ODS')
    print(sql)
    cursor.execute(sql)
    print(cursor.fetchall())
